pub struct StableNodeId<'a>(pub &'a str);Expand description
A string representation of a Tailscale node’s NodeId.
Different control plane servers should ideally have different StableNodeId suffixes for
different sites or regions.
Being a string, it’s safer to use in JavaScript without worrying about the size of the integer,
as documented on NodeId. But in general, Tailscale APIs can accept either a NodeId
integer or a StableNodeId string when referring to a node.
Tuple Fields
0: &'a strTrait Implementations
Sourceimpl<'a> Clone for StableNodeId<'a>
impl<'a> Clone for StableNodeId<'a>
Sourcefn clone(&self) -> StableNodeId<'a>
fn clone(&self) -> StableNodeId<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for StableNodeId<'a>
impl<'a> Debug for StableNodeId<'a>
Sourceimpl<'a> Default for StableNodeId<'a>
impl<'a> Default for StableNodeId<'a>
Sourcefn default() -> StableNodeId<'a>
fn default() -> StableNodeId<'a>
Returns the “default value” for a type. Read more
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for StableNodeId<'a>
impl<'de: 'a, 'a> Deserialize<'de> for StableNodeId<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for StableNodeId<'a>
Sourceimpl<'a> PartialEq for StableNodeId<'a>
impl<'a> PartialEq for StableNodeId<'a>
Sourceimpl<'a> Serialize for StableNodeId<'a>
impl<'a> Serialize for StableNodeId<'a>
impl<'a> StructuralPartialEq for StableNodeId<'a>