User

Struct User 

pub struct User<'a> {
    pub id: UserId,
    pub display_name: Option<Cow<'a, str>>,
    pub profile_pic_url: Option<Url>,
    pub created: Option<DateTime<Utc>>,
}
A Tailscale user.

A User can have multiple Logins associated with it (e.g. gmail and github oauth), although as of 2019, none of the UIs support this.

Some fields are inherited from the Logins and can be overridden, such as User::display_name and User::profile_pic_url.

Fields

id: UserId

The unique integer ID of this Tailscale user.

display_name: Option<Cow<'a, str>>

If populated, the display name of this Tailscale user. Overrides the value in any IdP- provided Login::display_name field.

profile_pic_url: Option<Url>

If populated, a URL to a profile picture representing this Tailscale user. Overrides the IdP-provided value in any Login::profile_pic_url field.

created: Option<DateTime<Utc>>

The date and time that this Tailscale user was created, in the UTC timezone.