pub struct ControlDialPlan<'a> {
pub candidates: Vec<ControlIpCandidate<'a>>,
}Expand description
Instructions from the control server to a Tailscale node on how to connect to the control server. Used to maintain connection if the node’s network state changes after the initial connection, or if the control server pushes other changes to the node (such as DNS config updates) that break connectivity.
Fields
candidates: Vec<ControlIpCandidate<'a>>The list of candidate IP addresses this Tailscale node should use to reach the control server. An empty list means the node should use any DNS resolver available to discover the control server’s IP address.