pub struct Debug {
pub sleep_seconds: Duration,
pub disable_log_tail: bool,
pub exit: Option<i64>,
}Expand description
Deprecated. A miscellaneous set of declarative debug config changes and imperative debug
commands sent from the control server to a Tailscale node. They’ve since been mostly
migrated to node attributes in Node::capabilities for
the declarative things and control-to-node (c2n) requests for the imperative things.
Not much remains here; don’t add more.
Fields
sleep_seconds: DurationRequests that this Tailscale node sleep for the provided number of seconds.
The node can (and should) limit the maximum time, such as 5 minutes. This exists as a safety measure to slow down spinning Tailscale nodes, in case we introduce a bug in the state machine.
disable_log_tail: boolDisables the logtail package in the Go client; ignored by the Rust client. Primarily
used by self-hosted control planes.
exit: Option<i64>If populated, indicates that this Tailscale node’s process should exit with the given return code. This is a safety measure in case a node is crash-looping or in an unsafe state and we need to remotely shut it down.